@@ -2,9 +2,8 @@
 
 from abc import abstractmethod
 import abc
-from typing import Union
+from typing import Type, Union
 from koil.exceptions import KoilException
-
 from koil.state import KoilState
 
 
@@ -18,6 +17,11 @@ class CheckerExpection(KoilException):
 class BaseChecker(abc.ABC):
     pass
 
+    def __init__(self, koil) -> None:
+        self.koil = koil
+        super().__init__()
+
+
     @abstractmethod
     def force_state(self) -> Union[None, KoilState]:
         """Force State
