@@ -1,6 +1,7 @@
 
 import threading
 import asyncio 
+from asyncio.runners import _cancel_all_tasks
 from threading import Thread
 import os
 import logging
@@ -11,10 +12,6 @@ from koil.state import KoilState
 
 logger = logging.getLogger(__name__)
 
-class HerreError(Exception):
-    pass
-
-
 
 def newloop(loop, loop_started):
     asyncio.set_event_loop(loop)
@@ -24,8 +21,12 @@ def newloop(loop, loop_started):
         loop.run_forever()
     finally:
         print("Loop Shutting Down")
-        loop.run_until_complete(loop.shutdown_asyncgens())
-        loop.close()
+        try:
+            _cancel_all_tasks(loop)
+            loop.run_until_complete(loop.shutdown_asyncgens())
+        finally:
+            asyncio.set_event_loop(None)
+            loop.close()
 
 
 class Koil:
@@ -51,12 +52,13 @@ class Koil:
 
         self.loop = None
         self.thread_id = None
-        self.state: KoilState = get_checker_registry(register_defaults=register_default_checkers).get_desired_state()
+        self.state = get_checker_registry(register_defaults=register_default_checkers).get_desired_state(self)
         
         if force_sync or force_async:
             self.state.threaded = force_sync and not force_async # Force async has priority
 
 
+
         if self.state.threaded:
             self.loop = asyncio.new_event_loop()
             self.loop_started_event = threading.Event()
@@ -74,12 +76,17 @@ class Koil:
         set_current_koil(self)
 
 
-    def close(self):
-        self.loop.call_soon_threadsafe(self.loop.stop())
+    async def aclose(self):
+        loop = asyncio.get_event_loop()
 
-        while self.loop.is_running():
-            print("Waiting to kill")
-            time.sleep(0.1)
+    def close(self):
+        # Do according to state
+        if self.state.threaded:
+            self.loop.call_soon_threadsafe(self.loop.stop())
+
+            while self.loop.is_running():
+                print("Waiting to kill")
+                time.sleep(0.1)
 
 
 
@@ -90,16 +97,18 @@ class KoiledContext():
 
     def __enter__(self):
         self.koil = Koil(force_sync=True)
-        return
+        return self.koil
 
     def __exit__(self,*args, **kwargs):
+        self.koil.close()
         return
 
     async def __aenter__(self):
         self.koil = Koil(force_async=True)
-        return
+        return self.koil
 
     async def __aexit__(self,*args, **kwargs):
+        await self.koil.aclose()
         self.koil = None
 
 
